RawBytesOptions

Struct RawBytesOptions 

pub struct RawBytesOptions<'env> { /* private fields */ }
Options for pure raw bytes databases (no serialization)

Implementations

Source

impl RawBytesOptions<'_>

pub fn name(self, name: &str) -> Self

Set the database name

pub fn unnamed_for_default(self) -> Self

Use unnamed database for default scope instead of a named database This is useful for backward compatibility with existing LMDB databases that store data in the unnamed database

pub fn create( self, txn: &mut RwTxn<'_>, ) -> Result<ScopedBytesDatabase, ScopedDbError>

Create the database with the current transaction