ScopedDatabaseOptions

Struct ScopedDatabaseOptions 

pub struct ScopedDatabaseOptions<'env> { /* private fields */ }
Builder for creating scoped databases with flexible type configurations

Implementations

Source

impl<'env> ScopedDatabaseOptions<'env>

pub fn new(env: &'env Env, global_registry: Arc<GlobalScopeRegistry>) -> Self

Create a new options builder

pub fn with_registry(self, _registry: Arc<GlobalScopeRegistry>) -> Self

Alias for backward compatibility

pub fn types<K, V>(self) -> TypedOptions<'env, K, V>
where K: Serialize + for<'de> Deserialize<'de> + Clone + 'static, V: Serialize + for<'de> Deserialize<'de> + 'static,

Configure database with generic key and value types using SerdeBincode Keys and values are serialized using bincode

pub fn bytes_keys<V>(self) -> BytesKeysOptions<'env, V>
where V: Serialize + for<'de> Deserialize<'de> + 'static,

Configure database with raw byte slice keys (&u8) and serialized values Keys are stored as-is without serialization, values use bincode

pub fn raw_bytes(self) -> RawBytesOptions<'env>

Configure database with raw byte slice keys and values (no serialization) Both keys and values are stored as raw bytes without any encoding