pub struct RawBytesOptions<'env> { /* private fields */ }Expand description
Options for pure raw bytes databases (no serialization)
Implementations
Sourceimpl RawBytesOptions<'_>
impl RawBytesOptions<'_>
Sourcepub fn unnamed_for_default(self) -> Self
pub fn unnamed_for_default(self) -> Self
Use unnamed database for default scope instead of a named database This is useful for backward compatibility with existing LMDB databases that store data in the unnamed database
Sourcepub fn create(
self,
txn: &mut RwTxn<'_>,
) -> Result<ScopedBytesDatabase, ScopedDbError>
pub fn create( self, txn: &mut RwTxn<'_>, ) -> Result<ScopedBytesDatabase, ScopedDbError>
Create the database with the current transaction